@@ -6,14 +6,14 @@ Type annotations for devops-guru service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_devops_guru.type_defs import AddNotificationChannelResponseTypeDef
+    from mypy_boto3_devops_guru.type_defs import AddNotificationChannelRequestRequestTypeDef
 
-    data: AddNotificationChannelResponseTypeDef = {...}
+    data: AddNotificationChannelRequestRequestTypeDef = {...}
     ```
 """
 import sys
 from datetime import datetime
-from typing import List
+from typing import Any, Dict, List, Union
 
 from .literals import (
     AnomalySeverityType,
@@ -27,8 +27,11 @@ from .literals import (
     InsightSeverityType,
     InsightStatusType,
     InsightTypeType,
+    LocaleType,
     OptInStatusType,
+    ResourceCollectionTypeType,
     ServiceNameType,
+    UpdateResourceCollectionActionType,
 )
 
 if sys.version_info >= (3, 8):
@@ -38,6 +41,7 @@ else:
 
 
 __all__ = (
+    "AddNotificationChannelRequestRequestTypeDef",
     "AddNotificationChannelResponseTypeDef",
     "AnomalySourceDetailsTypeDef",
     "AnomalyTimeRangeTypeDef",
@@ -50,30 +54,42 @@ __all__ = (
     "CostEstimationResourceCollectionFilterTypeDef",
     "CostEstimationTimeRangeTypeDef",
     "DescribeAccountHealthResponseTypeDef",
+    "DescribeAccountOverviewRequestRequestTypeDef",
     "DescribeAccountOverviewResponseTypeDef",
+    "DescribeAnomalyRequestRequestTypeDef",
     "DescribeAnomalyResponseTypeDef",
+    "DescribeFeedbackRequestRequestTypeDef",
     "DescribeFeedbackResponseTypeDef",
+    "DescribeInsightRequestRequestTypeDef",
     "DescribeInsightResponseTypeDef",
+    "DescribeResourceCollectionHealthRequestRequestTypeDef",
     "DescribeResourceCollectionHealthResponseTypeDef",
     "DescribeServiceIntegrationResponseTypeDef",
     "EndTimeRangeTypeDef",
     "EventResourceTypeDef",
     "EventTimeRangeTypeDef",
     "EventTypeDef",
+    "GetCostEstimationRequestRequestTypeDef",
     "GetCostEstimationResponseTypeDef",
+    "GetResourceCollectionRequestRequestTypeDef",
     "GetResourceCollectionResponseTypeDef",
     "InsightFeedbackTypeDef",
     "InsightHealthTypeDef",
     "InsightTimeRangeTypeDef",
+    "ListAnomaliesForInsightRequestRequestTypeDef",
     "ListAnomaliesForInsightResponseTypeDef",
     "ListEventsFiltersTypeDef",
+    "ListEventsRequestRequestTypeDef",
     "ListEventsResponseTypeDef",
     "ListInsightsAnyStatusFilterTypeDef",
     "ListInsightsClosedStatusFilterTypeDef",
     "ListInsightsOngoingStatusFilterTypeDef",
+    "ListInsightsRequestRequestTypeDef",
     "ListInsightsResponseTypeDef",
     "ListInsightsStatusFilterTypeDef",
+    "ListNotificationChannelsRequestRequestTypeDef",
     "ListNotificationChannelsResponseTypeDef",
+    "ListRecommendationsRequestRequestTypeDef",
     "ListRecommendationsResponseTypeDef",
     "NotificationChannelConfigTypeDef",
     "NotificationChannelTypeDef",
@@ -85,6 +101,7 @@ __all__ = (
     "ProactiveAnomalyTypeDef",
     "ProactiveInsightSummaryTypeDef",
     "ProactiveInsightTypeDef",
+    "PutFeedbackRequestRequestTypeDef",
     "ReactiveAnomalySummaryTypeDef",
     "ReactiveAnomalyTypeDef",
     "ReactiveInsightSummaryTypeDef",
@@ -96,9 +113,12 @@ __all__ = (
     "RecommendationRelatedEventResourceTypeDef",
     "RecommendationRelatedEventTypeDef",
     "RecommendationTypeDef",
+    "RemoveNotificationChannelRequestRequestTypeDef",
     "ResourceCollectionFilterTypeDef",
     "ResourceCollectionTypeDef",
+    "ResponseMetadataTypeDef",
     "SearchInsightsFiltersTypeDef",
+    "SearchInsightsRequestRequestTypeDef",
     "SearchInsightsResponseTypeDef",
     "ServiceCollectionTypeDef",
     "ServiceHealthTypeDef",
@@ -106,16 +126,27 @@ __all__ = (
     "ServiceIntegrationConfigTypeDef",
     "ServiceResourceCostTypeDef",
     "SnsChannelConfigTypeDef",
+    "StartCostEstimationRequestRequestTypeDef",
     "StartTimeRangeTypeDef",
     "UpdateCloudFormationCollectionFilterTypeDef",
     "UpdateResourceCollectionFilterTypeDef",
+    "UpdateResourceCollectionRequestRequestTypeDef",
     "UpdateServiceIntegrationConfigTypeDef",
+    "UpdateServiceIntegrationRequestRequestTypeDef",
+)
+
+AddNotificationChannelRequestRequestTypeDef = TypedDict(
+    "AddNotificationChannelRequestRequestTypeDef",
+    {
+        "Config": "NotificationChannelConfigTypeDef",
+    },
 )
 
 AddNotificationChannelResponseTypeDef = TypedDict(
     "AddNotificationChannelResponseTypeDef",
     {
         "Id": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -225,15 +256,46 @@ DescribeAccountHealthResponseTypeDef = TypedDict(
         "OpenProactiveInsights": int,
         "MetricsAnalyzed": int,
         "ResourceHours": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
+_RequiredDescribeAccountOverviewRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeAccountOverviewRequestRequestTypeDef",
+    {
+        "FromTime": Union[datetime, str],
+    },
+)
+_OptionalDescribeAccountOverviewRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeAccountOverviewRequestRequestTypeDef",
+    {
+        "ToTime": Union[datetime, str],
+    },
+    total=False,
+)
+
+
+class DescribeAccountOverviewRequestRequestTypeDef(
+    _RequiredDescribeAccountOverviewRequestRequestTypeDef,
+    _OptionalDescribeAccountOverviewRequestRequestTypeDef,
+):
+    pass
+
+
 DescribeAccountOverviewResponseTypeDef = TypedDict(
     "DescribeAccountOverviewResponseTypeDef",
     {
         "ReactiveInsights": int,
         "ProactiveInsights": int,
         "MeanTimeToRecoverInMilliseconds": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeAnomalyRequestRequestTypeDef = TypedDict(
+    "DescribeAnomalyRequestRequestTypeDef",
+    {
+        "Id": str,
     },
 )
 
@@ -242,6 +304,14 @@ DescribeAnomalyResponseTypeDef = TypedDict(
     {
         "ProactiveAnomaly": "ProactiveAnomalyTypeDef",
         "ReactiveAnomaly": "ReactiveAnomalyTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeFeedbackRequestRequestTypeDef = TypedDict(
+    "DescribeFeedbackRequestRequestTypeDef",
+    {
+        "InsightId": str,
     },
     total=False,
 )
@@ -250,8 +320,15 @@ DescribeFeedbackResponseTypeDef = TypedDict(
     "DescribeFeedbackResponseTypeDef",
     {
         "InsightFeedback": "InsightFeedbackTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeInsightRequestRequestTypeDef = TypedDict(
+    "DescribeInsightRequestRequestTypeDef",
+    {
+        "Id": str,
     },
-    total=False,
 )
 
 DescribeInsightResponseTypeDef = TypedDict(
@@ -259,46 +336,55 @@ DescribeInsightResponseTypeDef = TypedDict(
     {
         "ProactiveInsight": "ProactiveInsightTypeDef",
         "ReactiveInsight": "ReactiveInsightTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-_RequiredDescribeResourceCollectionHealthResponseTypeDef = TypedDict(
-    "_RequiredDescribeResourceCollectionHealthResponseTypeDef",
+_RequiredDescribeResourceCollectionHealthRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeResourceCollectionHealthRequestRequestTypeDef",
     {
-        "CloudFormation": List["CloudFormationHealthTypeDef"],
+        "ResourceCollectionType": ResourceCollectionTypeType,
     },
 )
-_OptionalDescribeResourceCollectionHealthResponseTypeDef = TypedDict(
-    "_OptionalDescribeResourceCollectionHealthResponseTypeDef",
+_OptionalDescribeResourceCollectionHealthRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeResourceCollectionHealthRequestRequestTypeDef",
     {
-        "Service": List["ServiceHealthTypeDef"],
         "NextToken": str,
     },
     total=False,
 )
 
 
-class DescribeResourceCollectionHealthResponseTypeDef(
-    _RequiredDescribeResourceCollectionHealthResponseTypeDef,
-    _OptionalDescribeResourceCollectionHealthResponseTypeDef,
+class DescribeResourceCollectionHealthRequestRequestTypeDef(
+    _RequiredDescribeResourceCollectionHealthRequestRequestTypeDef,
+    _OptionalDescribeResourceCollectionHealthRequestRequestTypeDef,
 ):
     pass
 
 
+DescribeResourceCollectionHealthResponseTypeDef = TypedDict(
+    "DescribeResourceCollectionHealthResponseTypeDef",
+    {
+        "CloudFormation": List["CloudFormationHealthTypeDef"],
+        "Service": List["ServiceHealthTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeServiceIntegrationResponseTypeDef = TypedDict(
     "DescribeServiceIntegrationResponseTypeDef",
     {
         "ServiceIntegration": "ServiceIntegrationConfigTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 EndTimeRangeTypeDef = TypedDict(
     "EndTimeRangeTypeDef",
     {
-        "FromTime": datetime,
-        "ToTime": datetime,
+        "FromTime": Union[datetime, str],
+        "ToTime": Union[datetime, str],
     },
     total=False,
 )
@@ -316,8 +402,8 @@ EventResourceTypeDef = TypedDict(
 EventTimeRangeTypeDef = TypedDict(
     "EventTimeRangeTypeDef",
     {
-        "FromTime": datetime,
-        "ToTime": datetime,
+        "FromTime": Union[datetime, str],
+        "ToTime": Union[datetime, str],
     },
 )
 
@@ -336,6 +422,14 @@ EventTypeDef = TypedDict(
     total=False,
 )
 
+GetCostEstimationRequestRequestTypeDef = TypedDict(
+    "GetCostEstimationRequestRequestTypeDef",
+    {
+        "NextToken": str,
+    },
+    total=False,
+)
+
 GetCostEstimationResponseTypeDef = TypedDict(
     "GetCostEstimationResponseTypeDef",
     {
@@ -345,17 +439,39 @@ GetCostEstimationResponseTypeDef = TypedDict(
         "TimeRange": "CostEstimationTimeRangeTypeDef",
         "TotalCost": float,
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetResourceCollectionRequestRequestTypeDef = TypedDict(
+    "_RequiredGetResourceCollectionRequestRequestTypeDef",
+    {
+        "ResourceCollectionType": ResourceCollectionTypeType,
+    },
+)
+_OptionalGetResourceCollectionRequestRequestTypeDef = TypedDict(
+    "_OptionalGetResourceCollectionRequestRequestTypeDef",
+    {
+        "NextToken": str,
     },
     total=False,
 )
 
+
+class GetResourceCollectionRequestRequestTypeDef(
+    _RequiredGetResourceCollectionRequestRequestTypeDef,
+    _OptionalGetResourceCollectionRequestRequestTypeDef,
+):
+    pass
+
+
 GetResourceCollectionResponseTypeDef = TypedDict(
     "GetResourceCollectionResponseTypeDef",
     {
         "ResourceCollection": "ResourceCollectionFilterTypeDef",
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 InsightFeedbackTypeDef = TypedDict(
@@ -396,14 +512,38 @@ class InsightTimeRangeTypeDef(_RequiredInsightTimeRangeTypeDef, _OptionalInsight
     pass
 
 
+_RequiredListAnomaliesForInsightRequestRequestTypeDef = TypedDict(
+    "_RequiredListAnomaliesForInsightRequestRequestTypeDef",
+    {
+        "InsightId": str,
+    },
+)
+_OptionalListAnomaliesForInsightRequestRequestTypeDef = TypedDict(
+    "_OptionalListAnomaliesForInsightRequestRequestTypeDef",
+    {
+        "StartTimeRange": "StartTimeRangeTypeDef",
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListAnomaliesForInsightRequestRequestTypeDef(
+    _RequiredListAnomaliesForInsightRequestRequestTypeDef,
+    _OptionalListAnomaliesForInsightRequestRequestTypeDef,
+):
+    pass
+
+
 ListAnomaliesForInsightResponseTypeDef = TypedDict(
     "ListAnomaliesForInsightResponseTypeDef",
     {
         "ProactiveAnomalies": List["ProactiveAnomalySummaryTypeDef"],
         "ReactiveAnomalies": List["ReactiveAnomalySummaryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ListEventsFiltersTypeDef = TypedDict(
@@ -419,27 +559,37 @@ ListEventsFiltersTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredListEventsResponseTypeDef = TypedDict(
-    "_RequiredListEventsResponseTypeDef",
+_RequiredListEventsRequestRequestTypeDef = TypedDict(
+    "_RequiredListEventsRequestRequestTypeDef",
     {
-        "Events": List["EventTypeDef"],
+        "Filters": "ListEventsFiltersTypeDef",
     },
 )
-_OptionalListEventsResponseTypeDef = TypedDict(
-    "_OptionalListEventsResponseTypeDef",
+_OptionalListEventsRequestRequestTypeDef = TypedDict(
+    "_OptionalListEventsRequestRequestTypeDef",
     {
+        "MaxResults": int,
         "NextToken": str,
     },
     total=False,
 )
 
 
-class ListEventsResponseTypeDef(
-    _RequiredListEventsResponseTypeDef, _OptionalListEventsResponseTypeDef
+class ListEventsRequestRequestTypeDef(
+    _RequiredListEventsRequestRequestTypeDef, _OptionalListEventsRequestRequestTypeDef
 ):
     pass
 
 
+ListEventsResponseTypeDef = TypedDict(
+    "ListEventsResponseTypeDef",
+    {
+        "Events": List["EventTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListInsightsAnyStatusFilterTypeDef = TypedDict(
     "ListInsightsAnyStatusFilterTypeDef",
     {
@@ -463,14 +613,36 @@ ListInsightsOngoingStatusFilterTypeDef = TypedDict(
     },
 )
 
+_RequiredListInsightsRequestRequestTypeDef = TypedDict(
+    "_RequiredListInsightsRequestRequestTypeDef",
+    {
+        "StatusFilter": "ListInsightsStatusFilterTypeDef",
+    },
+)
+_OptionalListInsightsRequestRequestTypeDef = TypedDict(
+    "_OptionalListInsightsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListInsightsRequestRequestTypeDef(
+    _RequiredListInsightsRequestRequestTypeDef, _OptionalListInsightsRequestRequestTypeDef
+):
+    pass
+
+
 ListInsightsResponseTypeDef = TypedDict(
     "ListInsightsResponseTypeDef",
     {
         "ProactiveInsights": List["ProactiveInsightSummaryTypeDef"],
         "ReactiveInsights": List["ReactiveInsightSummaryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ListInsightsStatusFilterTypeDef = TypedDict(
@@ -483,22 +655,53 @@ ListInsightsStatusFilterTypeDef = TypedDict(
     total=False,
 )
 
+ListNotificationChannelsRequestRequestTypeDef = TypedDict(
+    "ListNotificationChannelsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+    },
+    total=False,
+)
+
 ListNotificationChannelsResponseTypeDef = TypedDict(
     "ListNotificationChannelsResponseTypeDef",
     {
         "Channels": List["NotificationChannelTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListRecommendationsRequestRequestTypeDef = TypedDict(
+    "_RequiredListRecommendationsRequestRequestTypeDef",
+    {
+        "InsightId": str,
+    },
+)
+_OptionalListRecommendationsRequestRequestTypeDef = TypedDict(
+    "_OptionalListRecommendationsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "Locale": LocaleType,
     },
     total=False,
 )
 
+
+class ListRecommendationsRequestRequestTypeDef(
+    _RequiredListRecommendationsRequestRequestTypeDef,
+    _OptionalListRecommendationsRequestRequestTypeDef,
+):
+    pass
+
+
 ListRecommendationsResponseTypeDef = TypedDict(
     "ListRecommendationsResponseTypeDef",
     {
         "Recommendations": List["RecommendationTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 NotificationChannelConfigTypeDef = TypedDict(
@@ -628,6 +831,14 @@ ProactiveInsightTypeDef = TypedDict(
     total=False,
 )
 
+PutFeedbackRequestRequestTypeDef = TypedDict(
+    "PutFeedbackRequestRequestTypeDef",
+    {
+        "InsightFeedback": "InsightFeedbackTypeDef",
+    },
+    total=False,
+)
+
 ReactiveAnomalySummaryTypeDef = TypedDict(
     "ReactiveAnomalySummaryTypeDef",
     {
@@ -750,6 +961,13 @@ RecommendationTypeDef = TypedDict(
     total=False,
 )
 
+RemoveNotificationChannelRequestRequestTypeDef = TypedDict(
+    "RemoveNotificationChannelRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
 ResourceCollectionFilterTypeDef = TypedDict(
     "ResourceCollectionFilterTypeDef",
     {
@@ -766,6 +984,17 @@ ResourceCollectionTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 SearchInsightsFiltersTypeDef = TypedDict(
     "SearchInsightsFiltersTypeDef",
     {
@@ -777,14 +1006,38 @@ SearchInsightsFiltersTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredSearchInsightsRequestRequestTypeDef = TypedDict(
+    "_RequiredSearchInsightsRequestRequestTypeDef",
+    {
+        "StartTimeRange": "StartTimeRangeTypeDef",
+        "Type": InsightTypeType,
+    },
+)
+_OptionalSearchInsightsRequestRequestTypeDef = TypedDict(
+    "_OptionalSearchInsightsRequestRequestTypeDef",
+    {
+        "Filters": "SearchInsightsFiltersTypeDef",
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class SearchInsightsRequestRequestTypeDef(
+    _RequiredSearchInsightsRequestRequestTypeDef, _OptionalSearchInsightsRequestRequestTypeDef
+):
+    pass
+
+
 SearchInsightsResponseTypeDef = TypedDict(
     "SearchInsightsResponseTypeDef",
     {
         "ProactiveInsights": List["ProactiveInsightSummaryTypeDef"],
         "ReactiveInsights": List["ReactiveInsightSummaryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ServiceCollectionTypeDef = TypedDict(
@@ -841,11 +1094,33 @@ SnsChannelConfigTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredStartCostEstimationRequestRequestTypeDef = TypedDict(
+    "_RequiredStartCostEstimationRequestRequestTypeDef",
+    {
+        "ResourceCollection": "CostEstimationResourceCollectionFilterTypeDef",
+    },
+)
+_OptionalStartCostEstimationRequestRequestTypeDef = TypedDict(
+    "_OptionalStartCostEstimationRequestRequestTypeDef",
+    {
+        "ClientToken": str,
+    },
+    total=False,
+)
+
+
+class StartCostEstimationRequestRequestTypeDef(
+    _RequiredStartCostEstimationRequestRequestTypeDef,
+    _OptionalStartCostEstimationRequestRequestTypeDef,
+):
+    pass
+
+
 StartTimeRangeTypeDef = TypedDict(
     "StartTimeRangeTypeDef",
     {
-        "FromTime": datetime,
-        "ToTime": datetime,
+        "FromTime": Union[datetime, str],
+        "ToTime": Union[datetime, str],
     },
     total=False,
 )
@@ -866,6 +1141,14 @@ UpdateResourceCollectionFilterTypeDef = TypedDict(
     total=False,
 )
 
+UpdateResourceCollectionRequestRequestTypeDef = TypedDict(
+    "UpdateResourceCollectionRequestRequestTypeDef",
+    {
+        "Action": UpdateResourceCollectionActionType,
+        "ResourceCollection": "UpdateResourceCollectionFilterTypeDef",
+    },
+)
+
 UpdateServiceIntegrationConfigTypeDef = TypedDict(
     "UpdateServiceIntegrationConfigTypeDef",
     {
@@ -873,3 +1156,10 @@ UpdateServiceIntegrationConfigTypeDef = TypedDict(
     },
     total=False,
 )
+
+UpdateServiceIntegrationRequestRequestTypeDef = TypedDict(
+    "UpdateServiceIntegrationRequestRequestTypeDef",
+    {
+        "ServiceIntegration": "UpdateServiceIntegrationConfigTypeDef",
+    },
+)
